function createfigure(Y1, Y2, Y3)
%CREATEFIGURE(Y1,Y2,Y3)
%  Y1:  vector of y data
%  Y2:  vector of y data
%  Y3:  vector of y data

%  Auto-generated by MATLAB on 28-Jan-2009 14:27:53

% Create figure
figure1 = figure('XVisual',...
    '0x21 (TrueColor, depth 16, RGB mask 0xf800 0x07e0 0x001f)',...
    'PaperSize',[20.98 29.68]);

% Create axes
axes1 = axes('Parent',figure1,'Position',[0.2036 1.042 0.1455 0.8826],...
    'CameraUpVector',[1 0 0]);
box('on');
hold('all');

% Create plot
plot(Y1,'Parent',axes1);

% Create axes
axes2 = axes('Parent',figure1,'YTick',[0 0.5 1],...
    'XTickLabel',{'0','0.6','0.7','0.8','0.9','1','1.1','1.2','1.3','1.4','1.5'},...
    'XTick',zeros(1,0),...
    'Position',[0.3099 0.03785 0.1539 0.8425],...
    'CameraUpVector',[1 0 0]);
% Uncomment the following line to preserve the X-limits of the axes
% xlim([5000 1.5e+04]);
box('on');
hold('all');

% Create plot
plot(Y2,'Parent',axes2);

% Create axes
axes3 = axes('Parent',figure1,...
    'XTickLabel',{'6.00','7.00','8.00','9.00','10.00','11.00','12.00','13.00','14.00','15.00'},...
    'XTick',[6000 7000 8000 9000 1e+04 1.1e+04 1.2e+04 1.3e+04 1.4e+04 1.5e+04],...
    'Position',[0.05451 0.03543 0.1386 0.845],...
    'FontWeight','demi',...
    'CameraUpVector',[1 0 0]);
% Uncomment the following line to preserve the X-limits of the axes
% xlim([5000 1.5e+04]);
box('on');
hold('all');

% Create plot
plot(Y1,'Parent',axes3,'DisplayName','tw100');

% Create axes
axes4 = axes('Parent',figure1,'YTick',[0 0.5 1],'XTick',zeros(1,0),...
    'Position',[0.5185 0.03903 0.1539 0.8414],...
    'CameraUpVector',[1 0 0]);
% Uncomment the following line to preserve the X-limits of the axes
% xlim([5000 1.5e+04]);
box('on');
hold('all');

% Create plot
plot(Y3,'Parent',axes4);

% Create axes
axes5 = axes('Parent',figure1,'Position',[0.7301 0.0402 0.1386 0.8392]);
box('on');
hold('all');

% Create plot
plot(Y3,'Parent',axes5,'DisplayName','nuFRET(1,16).eff20(1:24981,1)');

% Create textbox
annotation(figure1,'textbox','String',{'tw=20'},'FontSize',14,...
    'FitBoxToText','off',...
    'LineStyle','none',...
    'Position',[0.5626 0.8931 0.06056 0.01667]);

% Create textbox
annotation(figure1,'textbox','String',{'tw=10'},'FontSize',14,...
    'FitBoxToText','off',...
    'LineStyle','none',...
    'Position',[0.7683 0.8912 0.07858 0.01863]);

% Create textbox
annotation(figure1,'textbox','String',{' tw=50'},'FontSize',14,...
    'FitBoxToText','off',...
    'LineStyle','none',...
    'Position',[0.3388 0.8941 0.1146 0.01569]);

% Create textbox
annotation(figure1,'textbox','String',{'    tw=100'},'FontSize',14,...
    'FitBoxToText','off',...
    'Position',[0.05355 0.8882 0.8143 0.02059]);

